RowReorder examples - Initialisation

# RowReorder example Initialisation

The following examples show the basic initialisation, features and options of RowReorder.

### Initialisation

- Basic initialisation
- Restricted column ordering
- Mobile support (Responsive integration)
- Full row selection
- Reorder event
- DataTables Scrolling
- Defaults

Please refer to the DataTables documentation for full information about its API properties and methods.
Additionally, there are a wide range of extensions and plug-ins which extend the capabilities of DataTables.

DataTables designed and created by SpryMedia Ltd © 2007-2016
DataTables is licensed under the MIT license.